Initialization functions
=================================

.. autoclass:: tomni.annotation_manager.main.AnnotationManager
   :members: from_dicts, from_binary_mask, from_labeled_mask
   :show-inheritance:
   :noindex:
